==> Pixabay.0.1.zip: js/script.js <==
const imgForm = document.querySelector("#search-form");
const q =  document.querySelector("#search");
const nbPage =  document.querySelector("#page");
const navpagination = document.querySelector("#searchPagination");
q.addEventListener("change", function(){nbPage.value='1'});
imgForm.addEventListener("submit", fetchImages);
const limit = 25;

function fetchImages(e) {
    
    e.preventDefault();
    const page = document.querySelector("#page").value;;
    const searchTerm = document.querySelector(".search").value;
    fetch(`https://pixabay.com/api/?key=${apikey}&q=${searchTerm}&image_type=photo&per_page=${limit}&page=${page}`).
    
    then(response => {return response.json();}).
    then(resp => {
        console.log(resp);
        let maxPage = Math.ceil(resp.total / limit);
        let pageNbr = page;
        let hitsArray = resp.hits;
        showImages(hitsArray);
        if(maxPage > 20) maxPage =20;
        pagination(maxPage,pageNbr);
        const alertMsg = document.querySelector(".alert-msg");
        if (hitsArray.length === 0) {
            alertMsg.innerHTML = " Essayer un autre mot";
            } else {
            alertMsg.innerHTML = "";
        }
        
        const text = document.querySelector(".search-text");
        text.innerHTML = `<h2>${searchTerm}: <small>page ${page} / ${maxPage}</small></h2>`; //${resp.total} trouvé(s).
        document.querySelector('#bottom').scrollIntoView();
        if (searchTerm && hitsArray.length === 0) {
            text.innerHTML = `
            <h1> ${searchTerm}:  ${hitsArray.length} </h1>
            `;
        }
        
    }).
    catch(err => console.log('err:' + err));
}



function showImages(hitsArray) {
    const results = document.querySelector(".results");
    //console.log(results);
    
    let output = '<div class="flex-images">';
    hitsArray.forEach(imgData => {
        output += `
        <div class="col-4 item" data-w="${imgData.imageWidth}"  data-h="${imgData.imageHeight}">
        <a href="${imgData.largeImageURL}" class="pixabayUpload">upload</a>
        <img src="${imgData.largeImageURL}"/>
        </div>
        `;
    });
    document.querySelector('.results').innerHTML = output;
    new setUploadLinks();
    new flexImages({ selector: '.flex-images', rowHeight: 140 });
}

// affichage
function callpage(position) {
    nbPage.value = position;
    document.querySelector('#bottom').scrollIntoView();
}

// boutons précédent/suivant
function pagination(totalPages, numpage) {
    let btnTag = "";
    let totalP = totalPages;
    // if page is greater than 1  then show the prev button
    // display prev button
    if (numpage > 1) {
        btnTag += `<button class="btn prev"onClick="callpage(${numpage - 1})">&lsaquo;</button>`;
    }
    
    if (numpage < totalPages ) {
        btnTag += `<button class="btn next"onClick="callpage(${++numpage})">&rsaquo;</button>`;
    }
    
    navpagination.innerHTML = btnTag;
}

// demande de fichier
function setUploadLinks() {  
    let myLinks= document.querySelectorAll('a.pixabayUpload')
    for (let lks of myLinks) {
        lks.addEventListener('click',function(e){
            e.preventDefault(); 
            e.stopPropagation();
            uploadImage('?url='+lks.href);
        }, false);
    }
    
}

// affichage fichier demandé et codes d'insertions
function dialogUploadedImage(imgArray) {
    const succeedUpload = document.querySelector("#medias-table tbody tr:first-child td:first-child");
    // on garde juste le nom du fichier
    let file = imgArray[3].replace(/\.[^/.]+$/, "");
    console.log(file); // Output: "file"
    let done = `<div id="justUploaded">
    <dialog open>
    <h2>Image <i>${file}</i></h2>
    <div><b>Lien:</b><code>${imgArray[5]}</code><div data-copy="${imgArray[5]}" title="Copier le lien dans le presse-papier" class="ico">&#128203;
    <div>lien copié</div>
    </div></div>
    <div><b>HTML:</b> 
    <code>&lt;img src="${imgArray[5]}" alt="${file} uploaded@pixabay" &gt;</code>
    <div data-copy="<img src='${imgArray[5]}' alt='${file} uploaded@pixabay'>" title="Copier le code dans le presse-papier" class="ico">&#128203;
    <div>code copié</div>
    </div> 
    
    </div>
    <div><b>Preview:</b> <img src="${imgArray[1]}${imgArray[3]}" alt="image prewiew"></div>
    <form method="dialog">
    <button type="button" onclick="this.closest('dialog').removeAttribute('open')">OK</button>
    </form>
    </dialog>
    </div>
    `;
    // insertion dans tbody pour beneficier de la fonction copy/paste native . affichage
    succeedUpload.insertAdjacentHTML('beforeend', done);
    
}

// telechargement depuis le serveur distant de pixabay
function uploadImage(ziHref) {
    let protocol=window.location.protocol;
    let domain=window.location.host;
    let url = window.location.pathname;
    
    fetch(protocol+url+ziHref).
    then(response => {        
    return response.json();}).
    then(resp => {
        console.log(resp);
        dialogUploadedImage(resp);
    }).
    catch(err => console.log('err:' + err));
    return
}

==> Pixabay.1.0.zip: js/script.js <==
const imgForm = document.querySelector("#search-form");
const q =  document.querySelector("#search");
const nbPage =  document.querySelector("#page");
const filesTable = document.querySelector('#medias-table-tbody');
const navpagination = document.querySelector("#searchPagination");
q.addEventListener("change", function(){nbPage.value='1'});
imgForm.addEventListener("submit", fetchImages);
const limit = 25;

function fetchImages(e) {
    
    e.preventDefault();
    const page = document.querySelector("#page").value;;
    const searchTerm = document.querySelector(".search").value;
    fetch(`https://pixabay.com/api/?key=${apikey}&q=${searchTerm}&image_type=photo&per_page=${limit}&page=${page}`).
    
    then(response => {return response.json();}).
    then(resp => {
        console.log(resp);
        let maxPage = Math.ceil(resp.total / limit);
        let pageNbr = page;
        let hitsArray = resp.hits;
        showImages(hitsArray);
        if(maxPage > 20) maxPage =20;
        pagination(maxPage,pageNbr);
        const alertMsg = document.querySelector(".alert-msg");
        if (hitsArray.length === 0) {
            alertMsg.innerHTML = " Essayer un autre mot";
            } else {
            alertMsg.innerHTML = "";
        }
        
        const text = document.querySelector(".search-text");
        text.innerHTML = `<h2>${searchTerm}: <small>page ${page} / ${maxPage}</small></h2>`; //${resp.total} trouvé(s).
        document.querySelector('#bottom').scrollIntoView();
        if (searchTerm && hitsArray.length === 0) {
            text.innerHTML = `
            <h1> ${searchTerm}:  ${hitsArray.length} </h1>
            `;
        }
        
    }).
    catch(err => console.log('err:' + err));
}



function showImages(hitsArray) {
    const results = document.querySelector(".results");
    //console.log(results);
    
    let output = '<div class="flex-images">';
    hitsArray.forEach(imgData => {
        output += `
        <div class="col-4 item" data-w="${imgData.imageWidth}"  data-h="${imgData.imageHeight}">
        <a href="${imgData.largeImageURL}" class="pixabayUpload">upload</a>
        <img src="${imgData.largeImageURL}"/>
        </div>
        `;
    });
    document.querySelector('.results').innerHTML = output;
    new setUploadLinks();
    new flexImages({ selector: '.flex-images', rowHeight: 140 });
}

// affichage
function callpage(position) {
    nbPage.value = position;
}

// boutons précédent/suivant
function pagination(totalPages, numpage) {
    let btnTag = "";
    let totalP = totalPages;
    // if page is greater than 1  then show the prev button
    // display prev button
    if (numpage > 1) {
        btnTag += `<button class="btn prev"onClick="callpage(${numpage - 1})">&lsaquo;</button>`;
    }
    
    if (numpage < totalPages ) {
        btnTag += `<button class="btn next"onClick="callpage(${++numpage})">&rsaquo;</button>`;
    }
    
    navpagination.innerHTML = btnTag;
}

// demande de fichier
function setUploadLinks() {  
    let myLinks= document.querySelectorAll('a.pixabayUpload')
    for (let lks of myLinks) {
        lks.addEventListener('click',function(e){
            e.preventDefault(); 
            e.stopPropagation();
            uploadImage('?banque=pixabay&url='+lks.href);
        }, false);
    }
    
}

// affichage fichier demandé et codes d'insertions
function dialogUploadedImage(imgArray) {
    const succeedUpload = document.querySelector("#medias-table tbody tr:first-child td:first-child");
    // on garde juste le nom du fichier
    let file = imgArray[3].replace(/\.[^/.]+$/, "");
    console.log(file); // Output: "file"
    let done = `<div id="justUploaded">
    <dialog open>
    <h2>Image <i>${file}</i></h2>
    <div><b>Lien:</b><code>${imgArray[5]}</code><div data-copy="${imgArray[5]}" title="Copier le lien dans le presse-papier" class="ico">&#128203;
    <div>lien copié</div>
    </div></div>
    <div><b>HTML:</b> 
    <code>&lt;img src="${imgArray[5]}" alt="${file} uploaded@pixabay" &gt;</code>
    <div data-copy="<img src='${imgArray[5]}' alt='${file} uploaded@pixabay'>" title="Copier le code dans le presse-papier" class="ico">&#128203;
    <div>code copié</div>
    </div> 
    
    </div>
    <div><b>Preview:</b> <img src="${imgArray[1]}${imgArray[3]}" alt="image prewiew"></div>
    <form method="dialog">
    <button type="button" onclick="this.closest('dialog').removeAttribute('open')">OK</button>
    </form>
    </dialog>
    </div>
    `;
   let addtr=`
    <tr>
        <td>
            <input type="checkbox" name="idFile[]" value="${imgArray[3]}">
        </td>
        <td class="icon">
            <a class="overlay" title="${imgArray[7]}" href="${imgArray[5]}">
                <img alt="${imgArray[7]}" src="../../data/${imgArray[8]}/${imgArray[7]}.tb.${imgArray[6]}" class="thumb">
            </a>
        </td>
        <td>
            <a class="imglink" onclick="this.target='_blank'" title="${imgArray[7]}" href="../../${imgArray[5]}">
                ${imgArray[3]}
            </a>
            <div data-copy="${imgArray[5]}" title="Copier le lien dans le presse-papier" class="ico">
                📋
                <div>Lien copié</div>
            </div>
            <div data-rename="../../${imgArray[5]}" title="Renommer fichier" class="ico">✎</div>
                <br>Miniature : 
                <a onclick="this.target='_blank'" title="${imgArray[7]}" href="../../data/${imgArray[8]}/${imgArray[7]}.tb.${imgArray[6]}">
                    ${imgArray[7]}.tb.${imgArray[6]}
                </a>
            <div data-copy="data/${imgArray[8]}/${imgArray[7]}.tb.${imgArray[6]}" title="Copier le lien dans le presse-papier" class="ico">
                📋
                <div>Lien copié</div>
            </div>
        </td>
        <td>.${imgArray[6]}</td>
        <td>
            <br></td>
        <td></td>
        <td>Now</td>
    </tr>`;
    // insertion dans tbody pour beneficier de la fonction copy/paste native . affichage
    succeedUpload.insertAdjacentHTML('beforeend', done);
    filesTable.insertAdjacentHTML('beforeend',addtr);
}

// telechargement depuis le serveur distant de pixabay
function uploadImage(ziHref) {
    let protocol=window.location.protocol;
    let domain=window.location.host;
    let url = window.location.pathname;
    console.log(url+ziHref)
    fetch(protocol+url+ziHref).
    then(response => {        
    return response.json();}).
    then(resp => {
        console.log(resp);
        dialogUploadedImage(resp);
    }).
    catch(err => console.log('err:' + err));
    return
}
